==> members-facade-1.0.2-20190508.035311-98-sources.jar: com/bizvane/members/facade/models/bo/GetMemberDeductionInfo.java <==
package com.bizvane.members.facade.models.bo;

import com.bizvane.members.facade.service.card.request.IntegralChangeRequestModel;

import java.math.BigDecimal;

/**
 * @author liufq
 */
public class GetMemberDeductionInfo extends IntegralChangeRequestModel {
    private BigDecimal balance;
    private Integer countIntegral;
    private BigDecimal discountRatio;
    private String petCard;
    private String brandCode;
    private String wxOpenId;
    private String wxUnionId;
    private String docno;

    public BigDecimal getBalance() {
        return balance;
    }

    public void setBalance(BigDecimal balance) {
        this.balance = balance;
    }

    public Integer getCountIntegral() {
        return countIntegral;
    }

    public void setCountIntegral(Integer countIntegral) {
        this.countIntegral = countIntegral;
    }

    public BigDecimal getDiscountRatio() {
        return discountRatio;
    }

    public void setDiscountRatio(BigDecimal discountRatio) {
        this.discountRatio = discountRatio;
    }

    public String getPetCard() {
        return petCard;
    }

    public void setPetCard(String petCard) {
        this.petCard = petCard;
    }

    public String getBrandCode() {
        return brandCode;
    }

    public void setBrandCode(String brandCode) {
        this.brandCode = brandCode;
    }

    public String getWxOpenId() {
        return wxOpenId;
    }

    public void setWxOpenId(String wxOpenId) {
        this.wxOpenId = wxOpenId;
    }

    public String getWxUnionId() {
        return wxUnionId;
    }

    public void setWxUnionId(String wxUnionId) {
        this.wxUnionId = wxUnionId;
    }

    public String getDocno() {
        return docno;
    }

    public void setDocno(String docno) {
        this.docno = docno;
    }
}

==> members-facade-1.0.2-20190820.123438-247-sources.jar: com/bizvane/members/facade/models/bo/GetMemberDeductionInfo.java <==
package com.bizvane.members.facade.models.bo;

import com.bizvane.members.facade.service.card.request.IntegralChangeRequestModel;

import java.math.BigDecimal;

/**
 * @author liufq
 */
public class GetMemberDeductionInfo extends IntegralChangeRequestModel {
    private BigDecimal balance;
    private Integer countIntegral;
    private BigDecimal discountRatio;
    private String petCard;
    private String brandCode;
    private String wxOpenId;
    private String wxUnionId;
    private String docno;
    private String wxPayVoucherNo;

    public BigDecimal getBalance() {
        return balance;
    }

    public void setBalance(BigDecimal balance) {
        this.balance = balance;
    }

    public Integer getCountIntegral() {
        return countIntegral;
    }

    public void setCountIntegral(Integer countIntegral) {
        this.countIntegral = countIntegral;
    }

    public BigDecimal getDiscountRatio() {
        return discountRatio;
    }

    public void setDiscountRatio(BigDecimal discountRatio) {
        this.discountRatio = discountRatio;
    }

    public String getPetCard() {
        return petCard;
    }

    public void setPetCard(String petCard) {
        this.petCard = petCard;
    }

    public String getBrandCode() {
        return brandCode;
    }

    public void setBrandCode(String brandCode) {
        this.brandCode = brandCode;
    }

    public String getWxOpenId() {
        return wxOpenId;
    }

    public void setWxOpenId(String wxOpenId) {
        this.wxOpenId = wxOpenId;
    }

    public String getWxUnionId() {
        return wxUnionId;
    }

    public void setWxUnionId(String wxUnionId) {
        this.wxUnionId = wxUnionId;
    }

    public String getDocno() {
        return docno;
    }

    public void setDocno(String docno) {
        this.docno = docno;
    }

    public String getWxPayVoucherNo() {
        return wxPayVoucherNo;
    }

    public void setWxPayVoucherNo(String wxPayVoucherNo) {
        this.wxPayVoucherNo = wxPayVoucherNo;
    }
}
